'use strict';

var react = require('react');

var MEDIA_QUERY = '(prefers-color-scheme: dark)';
var MODE_DARK = 'dark';
var MODE_LIGHT = 'light';

var isClient = function isClient() {
  return typeof window !== 'undefined';
};

var getMatchMedia = function getMatchMedia() {
  return isClient() ? window.matchMedia && window.matchMedia(MEDIA_QUERY) : undefined;
};

var getColorMode = function getColorMode(matchQueryList) {
  return matchQueryList && matchQueryList.matches ? MODE_DARK : MODE_LIGHT;
};

var getBindingEvents = function getBindingEvents(matchQueryList, handler) {
  if (matchQueryList && matchQueryList.addEventListener) {
    return {
      bindEvent: function bindEvent() {
        return matchQueryList.addEventListener('change', handler);
      },
      unbindEvent: function unbindEvent() {
        return matchQueryList.removeEventListener('change', handler);
      }
    };
  }

  return {
    bindEvent: function bindEvent() {
      return matchQueryList && matchQueryList.addListener(handler);
    },
    unbindEvent: function unbindEvent() {
      return matchQueryList && matchQueryList.removeListener(handler);
    }
  };
};

function useSystemColorMode() {
  var _useState = react.useState(getColorMode(getMatchMedia())),
      colorMode = _useState[0],
      setColorMode = _useState[1];

  var handleChange = function handleChange() {
    isClient() && window.requestAnimationFrame(function () {
      return setColorMode(getColorMode(getMatchMedia()));
    });
  };

  react.useEffect(function () {
    if (isClient()) {
      var _getBindingEvents = getBindingEvents(getMatchMedia(), handleChange),
          bindEvent = _getBindingEvents.bindEvent,
          unbindEvent = _getBindingEvents.unbindEvent;

      bindEvent();
      return unbindEvent;
    }
  }, []);
  return colorMode;
}

exports.useSystemColorMode = useSystemColorMode;
//# sourceMappingURL=react-use-system-color-mode.cjs.development.js.map
